GifCacheManager class
Constructors
- GifCacheManager()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addGifToCache(
ImageProvider< Object> image, {Duration? clearTimeout}) → Future<void> -
Add gif to cache
image- gif provider to cacheclearTimeout- afterTimeout remove gif from cache to avoid ram usage ifclearTimeoutis null - not call clear func. -
clear(
) → void - Clears all the stored gifs from the cache.
-
getGifByPath(
String gif) → GifInfo? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeCachedGif(
String key) → bool - Removes single gif from the cache.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited